{% extends "orga/cfp/base.html" %}
{% load i18n %}

{% block cfp_content %}

    <div class="alert alert-info">
        {% blocktrans trimmed %}
        Questions can help you sort out additional details with speakers, such as
        clothing sizes, special requirements such as dietary needs, or accomodation.
        Questions can be asked either on a per-submission level, or per speaker, as
        you see fit.
        {% endblocktrans %}
    </div>

    <legend>
        {% trans "Speaker questions" %}
        <div>
        <a href="{{request.event.cfp.urls.new_question }}" class="btn btn-secondary">
            <i class="fa fa-plus"></i>
            {% trans "Add a new question" %}
        </a>
        <a href="{{ request.event.cfp.urls.remind_questions }}" class="btn btn-info">{% trans "Send out reminders for unanswered questions" %}</a>
        </div>
    </legend>
    {% with questions=speaker_questions type='speaker' %}
        {% include 'orga/cfp/question_table.html' %}
    {% endwith %}
    </table>
    <legend>{% trans "Submission questions" %}</legend>
    {% with questions=submission_questions type='submission' %}
        {% include 'orga/cfp/question_table.html' %}
    {% endwith %}
    <legend>{% trans "Reviewer questions" %}</legend>
    {% with questions=reviewer_questions type='reviewer' %}
        {% include 'orga/cfp/question_table.html' %}
    {% endwith %}
{% endblock %}
