# Generated by Django 2.0.2 on 2018-03-04 13:52

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('person', '0014_speakerinformation'),
    ]

    operations = [
        migrations.AddField(
            model_name='speakerinformation',
            name='resource',
            field=models.FileField(blank=True, help_text='Please try to keep your upload small, preferably below 16 MB.', null=True, upload_to='', verbose_name='file'),
        ),
    ]
