# Generated by Django 2.0.1 on 2018-02-05 19:50

from django.db import migrations, models
import pretalx.submission.models.submission


class Migration(migrations.Migration):

    dependencies = [
        ('submission', '0019_submissiontype_deadline'),
    ]

    operations = [
        migrations.AddField(
            model_name='submission',
            name='image',
            field=models.ImageField(blank=True, help_text='Optional. Will be displayed publically.', null=True, upload_to=pretalx.submission.models.submission.submission_image_path, verbose_name='Talk image'),
        ),
    ]
