{% extends "orga/submission/base.html" %}
{% load i18n %}
{% load url_replace %}

{% block submission_content %}
    {% trans "Do you really want to change the state of this submission?" %}
    {% include "cfp/event/fragment_state.html" with state=submission.state %}
    <span class="fa fa-arrow-right"></span>
    {% include "cfp/event/fragment_state.html" with state=target %}
    <form method="post" action="">
        {% csrf_token %}
        <input type="hidden" name="next" value="{{ next }}">

        <div class="form-group pull-right">
            <a class="btn btn-secondary" href="{% if request.GET.from == 'list' %}{{ request.event.orga_urls.submissions }}{% else %}{{ submission.orga_urls.base }}{% endif %}">
                {% trans "Back" %}
            </a>
            <button type="submit" class="btn btn-danger">
                {% trans "Do it" %}
            </button>
        </div>
    </form>
{% endblock %}
