# Generated by Django 2.0.1 on 2018-01-22 22:14

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('person', '0011_speakerprofile_has_arrived'),
    ]

    operations = [
        migrations.AddField(
            model_name='user',
            name='is_administrator',
            field=models.BooleanField(default=False),
        ),
    ]
