{% extends "orga/mails/base.html" %}
{% load bootstrap4 %}
{% load i18n %}
{% load url_replace %}
{% block mail_content %}
    <legend>
        {% trans "Please confirm:" %}
    </legend>
    {{ question }}
    <form method="post">
        {% csrf_token %}
        <a href="{{ request.event.orga_urls.outbox }}" class="btn btn-info">
            {% trans "Back" %}
        </a>
        <button type="submit" class="btn btn-danger">
            {% trans "Yes" %}
        </button>
    </form>
{% endblock %}
